@@ -18,7 +18,8 @@ def export_avatar(
         vstitcher_data_path: str,
         vstitcher_launcher_file: str,
         work_path: str,
-        body_sizes: dict
+        body_sizes: dict,
+        person_sex: str
 ) -> str:
 
     # copy plugin script to VStitcher folder
@@ -36,6 +37,7 @@ def export_avatar(
     params = {
         'body_sizes': body_sizes,
         'work_path': work_path,
+        'person_sex': person_sex,
     }
 
     # save JSON params to file
